@@ -1,4 +1,4 @@
-/* Copyright 2017--2018 The Tor Project
+/* Copyright 2017--2020 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.metrics.collector.webstats;
@@ -15,7 +15,6 @@ import java.nio.file.attribute.BasicFileAttributes;
 import java.time.LocalDate;
 import java.util.Optional;
 import java.util.TreeMap;
-import java.util.stream.Stream;
 
 /**
  * Processes the given path and stores metadata for log files.
@@ -23,7 +22,8 @@ import java.util.stream.Stream;
 public class LogFileMap
     extends TreeMap<String, TreeMap<String, TreeMap<LocalDate, LogMetadata>>> {
 
-  private static final Logger log = LoggerFactory.getLogger(LogFileMap.class);
+  private static final Logger logger
+      = LoggerFactory.getLogger(LogFileMap.class);
 
   /**
    * The map to keep track of the logfiles by virtual host,
@@ -55,13 +55,13 @@ public class LogFileMap
 
         private FileVisitResult logIfError(Path path, IOException ex) {
           if (null != ex) {
-            log.warn("Cannot process '{}'.", path, ex);
+            logger.warn("Cannot process '{}'.", path, ex);
           }
           return FileVisitResult.CONTINUE;
         }
       });
     } catch (IOException ex) {
-      log.error("Cannot read directory '{}'.", startDir, ex);
+      logger.error("Cannot read directory '{}'.", startDir, ex);
     }
   }
 
@@ -74,30 +74,5 @@ public class LogFileMap
           k -> new TreeMap<>());
     physicalHosts.put(metadata.date, metadata);
   }
-
-  /**
-   * Takes the given metadata and returns the LogMetadata for the entry
-   * of the next day.
-   */
-  public Optional<LogMetadata> nextDayLogFor(LogMetadata metadata) {
-    TreeMap<String, TreeMap<LocalDate, LogMetadata>> virtualHosts
-        = this.get(metadata.virtualHost);
-    if (null == virtualHosts) {
-      return Optional.empty();
-    }
-    TreeMap<LocalDate, LogMetadata> physicalHosts
-        = virtualHosts.get(metadata.physicalHost);
-    if (null == physicalHosts) {
-      return Optional.empty();
-    }
-    return Optional.ofNullable(physicalHosts.get(metadata.date.plusDays(1)));
-  }
-
-  /** Returns a stream of all contained log metadata. */
-  public Stream<LogMetadata> metadataStream() {
-    return this.values().stream()
-        .flatMap((virtualHosts) -> virtualHosts.values().stream())
-        .flatMap((physicalHosts) -> physicalHosts.values().stream());
-  }
 }
 
