@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# Copyright 2016--2018 The Tor Project
+# Copyright 2016--2020 The Tor Project
 # See LICENSE for licensing information.
 #
 # Script for creating descriptor tarballs on a CollecTor instance,
@@ -10,7 +10,7 @@
 # Configuration section:
 # The following path should be adjusted, if the CollecTor server layout differs.
 # All paths should be given absolute.
-ARCHIVEDIR="/srv/collector.torproject.org/collector/archive"
+ARCHIVEDIR="/srv/collector.torproject.org/collector/indexed/archive"
 WORKDIR="/srv/collector.torproject.org/collector/tarballs"
 OUTDIR="/srv/collector.torproject.org/collector/out"
 TARBALLTARGETDIR="/srv/collector.torproject.org/collector/data"
@@ -40,6 +40,8 @@ TARBALLS=(
   exit-list-$YEARTWO-$MONTHTWO
   torperf-$YEARONE-$MONTHONE
   torperf-$YEARTWO-$MONTHTWO
+  onionperf-$YEARONE-$MONTHONE
+  onionperf-$YEARTWO-$MONTHTWO
   certs
   microdescs-$YEARONE-$MONTHONE
   microdescs-$YEARTWO-$MONTHTWO
@@ -63,6 +65,10 @@ TARBALLS=(
   snowflakes-$YEARTWO-$MONTHTWO
   bridge-pool-assignments-$YEARONE-$MONTHONE
   bridge-pool-assignments-$YEARTWO-$MONTHTWO
+  bridgedb-metrics-$YEARONE-$MONTHONE
+  bridgedb-metrics-$YEARTWO-$MONTHTWO
+  bridgestrap-$YEARONE-$MONTHONE
+  bridgestrap-$YEARTWO-$MONTHTWO
 )
 TARBALLS=($(printf "%s\n" "${TARBALLS[@]}" | uniq))
 
@@ -71,6 +77,8 @@ DIRECTORIES=(
   $OUTDIR/exit-lists/$YEARTWO/$MONTHTWO/
   $OUTDIR/torperf/$YEARONE/$MONTHONE/
   $OUTDIR/torperf/$YEARTWO/$MONTHTWO/
+  $OUTDIR/onionperf/$YEARONE/$MONTHONE/
+  $OUTDIR/onionperf/$YEARTWO/$MONTHTWO/
   $OUTDIR/relay-descriptors/certs/
   $OUTDIR/relay-descriptors/microdesc/$YEARONE/$MONTHONE
   $OUTDIR/relay-descriptors/microdesc/$YEARTWO/$MONTHTWO
@@ -94,6 +102,10 @@ DIRECTORIES=(
   $OUTDIR/snowflakes/$YEARTWO/$MONTHTWO/
   $OUTDIR/bridge-pool-assignments/$YEARONE/$MONTHONE/
   $OUTDIR/bridge-pool-assignments/$YEARTWO/$MONTHTWO/
+  $OUTDIR/bridgedb-metrics/$YEARONE/$MONTHONE/
+  $OUTDIR/bridgedb-metrics/$YEARTWO/$MONTHTWO/
+  $OUTDIR/bridgestrap/$YEARONE/$MONTHONE/
+  $OUTDIR/bridgestrap/$YEARTWO/$MONTHTWO/
 )
 DIRECTORIES=($(printf "%s\n" "${DIRECTORIES[@]}" | uniq))
 
@@ -174,6 +186,9 @@ ln -f -s -t $ARCHIVEDIR/relay-descriptors/bandwidths/ $TARBALLTARGETDIR/bandwidt
 mkdir -p $ARCHIVEDIR/torperf/
 ln -f -s -t $ARCHIVEDIR/torperf/ $TARBALLTARGETDIR/torperf-20??-??.tar.xz
 
+mkdir -p $ARCHIVEDIR/onionperf/
+ln -f -s -t $ARCHIVEDIR/onionperf/ $TARBALLTARGETDIR/onionperf-20??-??.tar.xz
+
 mkdir -p $ARCHIVEDIR/webstats/
 ln -f -s -t $ARCHIVEDIR/webstats/ $TARBALLTARGETDIR/webstats-20??-??.tar
 
@@ -183,4 +198,10 @@ ln -f -s -t $ARCHIVEDIR/snowflakes/ $TARBALLTARGETDIR/snowflakes-20??-??.tar.xz
 mkdir -p $ARCHIVEDIR/bridge-pool-assignments/
 ln -f -s -t $ARCHIVEDIR/bridge-pool-assignments/ $TARBALLTARGETDIR/bridge-pool-assignments-20??-??.tar.xz
 
+mkdir -p $ARCHIVEDIR/bridgedb-metrics/
+ln -f -s -t $ARCHIVEDIR/bridgedb-metrics/ $TARBALLTARGETDIR/bridgedb-metrics-20??-??.tar.xz
+
+mkdir -p $ARCHIVEDIR/bridgestrap/
+ln -f -s -t $ARCHIVEDIR/bridgestrap/ $TARBALLTARGETDIR/bridgestrap-20??-??.tar.xz
+
 echo `date` "Finished."
