@@ -1,4 +1,4 @@
-/* Copyright 2016--2018 The Tor Project
+/* Copyright 2016--2020 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.metrics.collector.cron;
@@ -70,6 +70,8 @@ public class CollecTorMainTest {
         case "Relay":
         case "Bridge":
         case "BridgePoolAssignments":
+        case "BridgedbMetrics":
+        case "BridgestrapStats":
         case "Exitlist":
         case "OnionPerf":
         case "Webstats":
