@@ -1,10 +1,9 @@
-/* Copyright 2016--2018 The Tor Project
+/* Copyright 2016--2020 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.metrics.collector.sync;
 
 import java.io.File;
-import java.io.IOException;
 import java.nio.file.FileVisitResult;
 import java.nio.file.Path;
 import java.nio.file.SimpleFileVisitor;
@@ -20,8 +19,7 @@ public class FileCollector extends SimpleFileVisitor<Path> {
   }
 
   @Override
-  public FileVisitResult visitFile(Path file, BasicFileAttributes attrs)
-      throws IOException {
+  public FileVisitResult visitFile(Path file, BasicFileAttributes attrs) {
     this.list.add(file.toFile());
     return FileVisitResult.CONTINUE;
   }
